pub struct ReaderOptions {
pub stop_after_first_error: bool,
pub stop_after_eof: bool,
}Fields
stop_after_first_error: boolA flag indicating that iteration should stop on first failure.
stop_after_eof: boolA flag indicating that iteration should stop on first EOF record encountered.